@@ -19,6 +19,7 @@ class DatabaseConnector(AbstractDatabaseConnector, AsyncInitable, AsyncDeinitabl
     @dataclass
     class Config:
         address: str
+        auto_table_creation_enabled: bool = True
         pool_size: int = 5  # Pool size is the maximum number of permanent connections to keep
         max_overflow: int = 3  # Temporarily exceeds the set pool_size if no connections are available
         pool_recycle: int = -1  # Maximum number of seconds a connection can persist. It defaults to -1 (no timeout).
@@ -47,7 +48,8 @@ class DatabaseConnector(AbstractDatabaseConnector, AsyncInitable, AsyncDeinitabl
             pool_recycle=self._config.pool_recycle, pool_timeout=self._config.pool_timeout)
 
     async def _async_init(self):
-        await self.prepare_db(sqlalchemy_mapper_registry)
+        if self._config.auto_table_creation_enabled:
+            await self.prepare_db(sqlalchemy_mapper_registry)
 
     async def _async_deinit(self):
         await self.engine.dispose()
